import json
from jsonschema import ValidationError, validate


class Hydro1D:
    def __init__(self, path) -> None:
        self.schema = {
            "type": "object",
            "properties": {
                "name": {"type": "string"},
                "schema": {"type": "string"},
            },
            "required": ["name"],
        }

        self.path = path
        self.data = self.load_data()
        self.valid = self.validate_data()

    def load_data(self) -> dict:
        with open(self.path) as f:
            try:
                data = json.load(f)
            except json.decoder.JSONDecodeError:
                # TODO Implement propper error handling
                raise ValueError("Invalid JSON file")
        return data

    def validate_data(self) -> bool:
        if len(self.data) > 1:
            return False
        try:
            obj = list(self.data.keys())[0]
            validate(self.data[obj], schema=self.schema)
        except ValidationError as e:
            return False
        return True



from hesmapy.hydro.base import Hydro1D


def load_hydro_1d(path):
    """Load a 1D hydrological model from a JSON file.

    Parameters
    ----------
    path : str
        Path to the JSON file.

    Returns
    -------
    hydro : Hydro1D
        Hydro1D object.

    """
    return Hydro1D(path)



import unittest
import os
import json
from tempfile import NamedTemporaryFile
from hesmapy.hydro.base import Hydro1D


class TestHydro1D(unittest.TestCase):
    def setUp(self):
        self.valid_data = {"model": {"name": "test", "schema": "test_schema"}}
        self.invalid_data = {"invalid": "data"}

    def test_load_data_valid(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            json.dump(self.valid_data, f)
            path = f.name
        hydro = Hydro1D(path)
        os.unlink(path)
        self.assertEqual(hydro.data, self.valid_data)

    def test_load_data_invalid(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            f.write("invalid json")
            path = f.name
        with self.assertRaises(ValueError):
            Hydro1D(path)
        os.unlink(path)

    def test_validate_data_valid(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            json.dump(self.valid_data, f)
            path = f.name
        hydro = Hydro1D(path)
        os.unlink(path)
        self.assertTrue(hydro.valid)

    def test_validate_data_invalid_schema(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            json.dump(self.invalid_data, f)
            path = f.name
        hydro = Hydro1D(path)
        os.unlink(path)
        self.assertFalse(hydro.valid)

    def test_validate_data_multiple_objects(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            json.dump([self.valid_data, self.valid_data], f)
            path = f.name
        hydro = Hydro1D(path)
        os.unlink(path)
        self.assertFalse(hydro.valid)


if __name__ == "__main__":
    unittest.main()



import unittest
import os
import json
from tempfile import NamedTemporaryFile
from hesmapy.base import load_hydro_1d, Hydro1D


class TestLoadHydro1D(unittest.TestCase):
    def setUp(self):
        self.valid_data = {"model": {"name": "test", "schema": "test_schema"}}

    def test_load_hydro_1d(self):
        with NamedTemporaryFile(mode="w", delete=False) as f:
            json.dump(self.valid_data, f)
            path = f.name
        hydro = load_hydro_1d(path)
        os.unlink(path)
        self.assertIsInstance(hydro, Hydro1D)


if __name__ == "__main__":
    unittest.main()
